# ![Rummage](images/rummage.svg){: .svg-logo} Rummage

## Overview

Rummage is a cross platform search and replace tool. Rummage crawls directories and searches for specified patterns
(either regular expression or literal) and can optionally replace those targets with desired text.

Rummage is written in Python and is currently available on Python 3. Rummage by default uses Python's Re regular
expression engine, but you can also use the fantastic, feature rich [Regex][regex] search engine and do interesting
things like fuzzy searching and more.

![Search Tab](images/preview.png)

![Files Tab](images/files_tab.png)

![Content Tab](images/content_tab.png)

<style>
h1 {text-align: center;}
.svg-logo {display: inline; padding: 0; margin: 0; height: 48px; width: 48px; vertical-align: bottom;}
</style>

--8<-- "links.txt"
